# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_explorer_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_explorer_rpc.proto\x12\x16injective_explorer_rpc\"\xdf\x01\n\x14GetAccountTxsRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06\x62\x65\x66ore\x18\x02 \x01(\x04\x12\r\n\x05\x61\x66ter\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x0e\n\x06module\x18\x07 \x01(\t\x12\x13\n\x0b\x66rom_number\x18\x08 \x01(\x12\x12\x11\n\tto_number\x18\t \x01(\x12\x12\x12\n\nstart_time\x18\n \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x0b \x01(\x12\x12\x0e\n\x06status\x18\x0c \x01(\t\"{\n\x15GetAccountTxsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.TxDetailData\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t\"\xe7\x03\n\x0cTxDetailData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0c\n\x04info\x18\x08 \x01(\t\x12\x12\n\ngas_wanted\x18\t \x01(\x12\x12\x10\n\x08gas_used\x18\n \x01(\x12\x12/\n\x07gas_fee\x18\x0b \x01(\x0b\x32\x1e.injective_explorer_rpc.GasFee\x12\x11\n\tcodespace\x18\x0c \x01(\t\x12-\n\x06\x65vents\x18\r \x03(\x0b\x32\x1d.injective_explorer_rpc.Event\x12\x0f\n\x07tx_type\x18\x0e \x01(\t\x12\x10\n\x08messages\x18\x0f \x01(\x0c\x12\x35\n\nsignatures\x18\x10 \x03(\x0b\x32!.injective_explorer_rpc.Signature\x12\x0c\n\x04memo\x18\x11 \x01(\t\x12\x11\n\ttx_number\x18\x12 \x01(\x04\x12\x1c\n\x14\x62lock_unix_timestamp\x18\x13 \x01(\x04\x12\x11\n\terror_log\x18\x14 \x01(\t\x12\x0c\n\x04logs\x18\x15 \x01(\x0c\x12\x11\n\tclaim_ids\x18\x16 \x03(\x12\"o\n\x06GasFee\x12\x32\n\x06\x61mount\x18\x01 \x03(\x0b\x32\".injective_explorer_rpc.CosmosCoin\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\r\n\x05payer\x18\x03 \x01(\t\x12\x0f\n\x07granter\x18\x04 \x01(\t\"+\n\nCosmosCoin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x8b\x01\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x41\n\nattributes\x18\x02 \x03(\x0b\x32-.injective_explorer_rpc.Event.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\tSignature\x12\x0e\n\x06pubkey\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x11\n\tsignature\x18\x04 \x01(\t\"m\n\x15GetContractTxsRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x11\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\x13\n\x0b\x66rom_number\x18\x04 \x01(\x12\x12\x11\n\tto_number\x18\x05 \x01(\x12\"|\n\x16GetContractTxsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.TxDetailData\"@\n\x10GetBlocksRequest\x12\x0e\n\x06\x62\x65\x66ore\x18\x01 \x01(\x04\x12\r\n\x05\x61\x66ter\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x11\"t\n\x11GetBlocksResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12/\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32!.injective_explorer_rpc.BlockInfo\"\xd4\x01\n\tBlockInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x10\n\x08proposer\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x12\n\nblock_hash\x18\x04 \x01(\t\x12\x13\n\x0bparent_hash\x18\x05 \x01(\t\x12\x17\n\x0fnum_pre_commits\x18\x06 \x01(\x12\x12\x0f\n\x07num_txs\x18\x07 \x01(\x12\x12.\n\x03txs\x18\x08 \x03(\x0b\x32!.injective_explorer_rpc.TxDataRPC\x12\x11\n\ttimestamp\x18\t \x01(\t\"\xc0\x01\n\tTxDataRPC\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x11\n\tcodespace\x18\x05 \x01(\t\x12\x10\n\x08messages\x18\x06 \x01(\t\x12\x11\n\ttx_number\x18\x07 \x01(\x04\x12\x11\n\terror_log\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\r\x12\x11\n\tclaim_ids\x18\n \x03(\x12\"\x1d\n\x0fGetBlockRequest\x12\n\n\x02id\x18\x01 \x01(\t\"d\n\x10GetBlockResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12\x35\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\'.injective_explorer_rpc.BlockDetailInfo\"\xea\x01\n\x0f\x42lockDetailInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x10\n\x08proposer\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x12\n\nblock_hash\x18\x04 \x01(\t\x12\x13\n\x0bparent_hash\x18\x05 \x01(\t\x12\x17\n\x0fnum_pre_commits\x18\x06 \x01(\x12\x12\x0f\n\x07num_txs\x18\x07 \x01(\x12\x12\x11\n\ttotal_txs\x18\x08 \x01(\x12\x12+\n\x03txs\x18\t \x03(\x0b\x32\x1e.injective_explorer_rpc.TxData\x12\x11\n\ttimestamp\x18\n \x01(\t\"\xe1\x01\n\x06TxData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x11\n\tcodespace\x18\x05 \x01(\t\x12\x10\n\x08messages\x18\x06 \x01(\x0c\x12\x11\n\ttx_number\x18\x07 \x01(\x04\x12\x11\n\terror_log\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\r\x12\x14\n\x0ctx_msg_types\x18\n \x01(\x0c\x12\x0c\n\x04logs\x18\x0b \x01(\x0c\x12\x11\n\tclaim_ids\x18\x0c \x03(\x12\"\x16\n\x14GetValidatorsRequest\"c\n\x15GetValidatorsResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12/\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32!.injective_explorer_rpc.Validator\"\x83\x05\n\tValidator\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07moniker\x18\x02 \x01(\t\x12\x18\n\x10operator_address\x18\x03 \x01(\t\x12\x19\n\x11\x63onsensus_address\x18\x04 \x01(\t\x12\x0e\n\x06jailed\x18\x05 \x01(\x08\x12\x0e\n\x06status\x18\x06 \x01(\x11\x12\x0e\n\x06tokens\x18\x07 \x01(\t\x12\x18\n\x10\x64\x65legator_shares\x18\x08 \x01(\t\x12\x41\n\x0b\x64\x65scription\x18\t \x01(\x0b\x32,.injective_explorer_rpc.ValidatorDescription\x12\x18\n\x10unbonding_height\x18\n \x01(\x12\x12\x16\n\x0eunbonding_time\x18\x0b \x01(\t\x12\x17\n\x0f\x63ommission_rate\x18\x0c \x01(\t\x12\x1b\n\x13\x63ommission_max_rate\x18\r \x01(\t\x12\"\n\x1a\x63ommission_max_change_rate\x18\x0e \x01(\t\x12\x1e\n\x16\x63ommission_update_time\x18\x0f \x01(\t\x12\x10\n\x08proposed\x18\x10 \x01(\x04\x12\x0e\n\x06signed\x18\x11 \x01(\x04\x12\x0e\n\x06missed\x18\x12 \x01(\x04\x12\x11\n\ttimestamp\x18\x13 \x01(\t\x12\x38\n\x07uptimes\x18\x14 \x03(\x0b\x32\'.injective_explorer_rpc.ValidatorUptime\x12>\n\x0fslashing_events\x18\x15 \x03(\x0b\x32%.injective_explorer_rpc.SlashingEvent\x12\x19\n\x11uptime_percentage\x18\x16 \x01(\x01\x12\x11\n\timage_url\x18\x17 \x01(\t\"\x88\x01\n\x14ValidatorDescription\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x18\n\x10security_contact\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\"7\n\x0fValidatorUptime\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x95\x01\n\rSlashingEvent\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\r\n\x05power\x18\x04 \x01(\x04\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0e\n\x06jailed\x18\x06 \x01(\t\x12\x15\n\rmissed_blocks\x18\x07 \x01(\x04\"&\n\x13GetValidatorRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"b\n\x14GetValidatorResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12/\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32!.injective_explorer_rpc.Validator\",\n\x19GetValidatorUptimeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"n\n\x1aGetValidatorUptimeResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12\x35\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\'.injective_explorer_rpc.ValidatorUptime\"\xc7\x01\n\rGetTxsRequest\x12\x0e\n\x06\x62\x65\x66ore\x18\x01 \x01(\x04\x12\r\n\x05\x61\x66ter\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0e\n\x06module\x18\x06 \x01(\t\x12\x13\n\x0b\x66rom_number\x18\x07 \x01(\x12\x12\x11\n\tto_number\x18\x08 \x01(\x12\x12\x12\n\nstart_time\x18\t \x01(\x12\x12\x10\n\x08\x65nd_time\x18\n \x01(\x12\x12\x0e\n\x06status\x18\x0b \x01(\t\"n\n\x0eGetTxsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12,\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x1e.injective_explorer_rpc.TxData\"$\n\x14GetTxByTxHashRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"f\n\x15GetTxByTxHashResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12\x32\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32$.injective_explorer_rpc.TxDetailData\"Z\n\x19GetPeggyDepositTxsRequest\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x0c\n\x04skip\x18\x04 \x01(\x04\"S\n\x1aGetPeggyDepositTxsResponse\x12\x35\n\x05\x66ield\x18\x01 \x03(\x0b\x32&.injective_explorer_rpc.PeggyDepositTx\"\xf8\x01\n\x0ePeggyDepositTx\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x13\n\x0b\x65vent_nonce\x18\x03 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x04 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x05 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x06 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12\x12\n\nclaim_type\x18\t \x01(\x11\x12\x11\n\ttx_hashes\x18\n \x03(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\t\"]\n\x1cGetPeggyWithdrawalTxsRequest\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x0c\n\x04skip\x18\x04 \x01(\x04\"Y\n\x1dGetPeggyWithdrawalTxsResponse\x12\x38\n\x05\x66ield\x18\x01 \x03(\x0b\x32).injective_explorer_rpc.PeggyWithdrawalTx\"\xd3\x02\n\x11PeggyWithdrawalTx\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x04 \x01(\t\x12\x12\n\nbridge_fee\x18\x05 \x01(\t\x12\x16\n\x0eoutgoing_tx_id\x18\x06 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x07 \x01(\x04\x12\x13\n\x0b\x62\x61tch_nonce\x18\x08 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\t \x01(\t\x12\x13\n\x0b\x65vent_nonce\x18\n \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x0b \x01(\x04\x12\r\n\x05state\x18\x0c \x01(\t\x12\x12\n\nclaim_type\x18\r \x01(\x11\x12\x11\n\ttx_hashes\x18\x0e \x03(\t\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\t\"\xa9\x01\n\x18GetIBCTransferTxsRequest\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x13\n\x0bsrc_channel\x18\x03 \x01(\t\x12\x10\n\x08src_port\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65st_channel\x18\x05 \x01(\t\x12\x11\n\tdest_port\x18\x06 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\x11\x12\x0c\n\x04skip\x18\x08 \x01(\x04\"Q\n\x19GetIBCTransferTxsResponse\x12\x34\n\x05\x66ield\x18\x01 \x03(\x0b\x32%.injective_explorer_rpc.IBCTransferTx\"\xdc\x02\n\rIBCTransferTx\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x13\n\x0bsource_port\x18\x03 \x01(\t\x12\x16\n\x0esource_channel\x18\x04 \x01(\t\x12\x18\n\x10\x64\x65stination_port\x18\x05 \x01(\t\x12\x1b\n\x13\x64\x65stination_channel\x18\x06 \x01(\t\x12\x0e\n\x06\x61mount\x18\x07 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x08 \x01(\t\x12\x16\n\x0etimeout_height\x18\t \x01(\t\x12\x19\n\x11timeout_timestamp\x18\n \x01(\x04\x12\x17\n\x0fpacket_sequence\x18\x0b \x01(\x04\x12\x10\n\x08\x64\x61ta_hex\x18\x0c \x01(\x0c\x12\r\n\x05state\x18\r \x01(\t\x12\x11\n\ttx_hashes\x18\x0e \x03(\t\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\t\"L\n\x13GetWasmCodesRequest\x12\r\n\x05limit\x18\x01 \x01(\x11\x12\x13\n\x0b\x66rom_number\x18\x02 \x01(\x12\x12\x11\n\tto_number\x18\x03 \x01(\x12\"v\n\x14GetWasmCodesResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12.\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .injective_explorer_rpc.WasmCode\"\xd5\x02\n\x08WasmCode\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12\x0f\n\x07tx_hash\x18\x02 \x01(\t\x12\x32\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .injective_explorer_rpc.Checksum\x12\x12\n\ncreated_at\x18\x04 \x01(\x04\x12\x15\n\rcontract_type\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12>\n\npermission\x18\x07 \x01(\x0b\x32*.injective_explorer_rpc.ContractPermission\x12\x13\n\x0b\x63ode_schema\x18\x08 \x01(\t\x12\x11\n\tcode_view\x18\t \x01(\t\x12\x14\n\x0cinstantiates\x18\n \x01(\x04\x12\x0f\n\x07\x63reator\x18\x0b \x01(\t\x12\x13\n\x0b\x63ode_number\x18\x0c \x01(\x12\x12\x13\n\x0bproposal_id\x18\r \x01(\x12\"+\n\x08\x43hecksum\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\":\n\x12\x43ontractPermission\x12\x13\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x11\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\")\n\x16GetWasmCodeByIDRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x12\"\xe4\x02\n\x17GetWasmCodeByIDResponse\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12\x0f\n\x07tx_hash\x18\x02 \x01(\t\x12\x32\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .injective_explorer_rpc.Checksum\x12\x12\n\ncreated_at\x18\x04 \x01(\x04\x12\x15\n\rcontract_type\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12>\n\npermission\x18\x07 \x01(\x0b\x32*.injective_explorer_rpc.ContractPermission\x12\x13\n\x0b\x63ode_schema\x18\x08 \x01(\t\x12\x11\n\tcode_view\x18\t \x01(\t\x12\x14\n\x0cinstantiates\x18\n \x01(\x04\x12\x0f\n\x07\x63reator\x18\x0b \x01(\t\x12\x13\n\x0b\x63ode_number\x18\x0c \x01(\x12\x12\x13\n\x0bproposal_id\x18\r \x01(\x12\"\x93\x01\n\x17GetWasmContractsRequest\x12\r\n\x05limit\x18\x01 \x01(\x11\x12\x0f\n\x07\x63ode_id\x18\x02 \x01(\x12\x12\x13\n\x0b\x66rom_number\x18\x03 \x01(\x12\x12\x11\n\tto_number\x18\x04 \x01(\x12\x12\x13\n\x0b\x61ssets_only\x18\x05 \x01(\x08\x12\x0c\n\x04skip\x18\x06 \x01(\x12\x12\r\n\x05label\x18\x07 \x01(\t\"~\n\x18GetWasmContractsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.WasmContract\"\xab\x03\n\x0cWasmContract\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12\x10\n\x08\x65xecutes\x18\x05 \x01(\x04\x12\x17\n\x0finstantiated_at\x18\x06 \x01(\x04\x12\x14\n\x0cinit_message\x18\x07 \x01(\t\x12\x18\n\x10last_executed_at\x18\x08 \x01(\x04\x12\x33\n\x05\x66unds\x18\t \x03(\x0b\x32$.injective_explorer_rpc.ContractFund\x12\x0f\n\x07\x63ode_id\x18\n \x01(\x04\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x1f\n\x17\x63urrent_migrate_message\x18\x0c \x01(\t\x12\x17\n\x0f\x63ontract_number\x18\r \x01(\x12\x12\x0f\n\x07version\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12;\n\rcw20_metadata\x18\x10 \x01(\x0b\x32$.injective_explorer_rpc.Cw20Metadata\x12\x13\n\x0bproposal_id\x18\x11 \x01(\x12\"-\n\x0c\x43ontractFund\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x8c\x01\n\x0c\x43w20Metadata\x12\x39\n\ntoken_info\x18\x01 \x01(\x0b\x32%.injective_explorer_rpc.Cw20TokenInfo\x12\x41\n\x0emarketing_info\x18\x02 \x01(\x0b\x32).injective_explorer_rpc.Cw20MarketingInfo\"U\n\rCw20TokenInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x03 \x01(\x12\x12\x14\n\x0ctotal_supply\x18\x04 \x01(\t\"Z\n\x11\x43w20MarketingInfo\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04logo\x18\x03 \x01(\t\x12\x11\n\tmarketing\x18\x04 \x01(\x0c\";\n\x1fGetWasmContractByAddressRequest\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\"\xbf\x03\n GetWasmContractByAddressResponse\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12\x10\n\x08\x65xecutes\x18\x05 \x01(\x04\x12\x17\n\x0finstantiated_at\x18\x06 \x01(\x04\x12\x14\n\x0cinit_message\x18\x07 \x01(\t\x12\x18\n\x10last_executed_at\x18\x08 \x01(\x04\x12\x33\n\x05\x66unds\x18\t \x03(\x0b\x32$.injective_explorer_rpc.ContractFund\x12\x0f\n\x07\x63ode_id\x18\n \x01(\x04\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x1f\n\x17\x63urrent_migrate_message\x18\x0c \x01(\t\x12\x17\n\x0f\x63ontract_number\x18\r \x01(\x12\x12\x0f\n\x07version\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12;\n\rcw20_metadata\x18\x10 \x01(\x0b\x32$.injective_explorer_rpc.Cw20Metadata\x12\x13\n\x0bproposal_id\x18\x11 \x01(\x12\"7\n\x15GetCw20BalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x11\"P\n\x16GetCw20BalanceResponse\x12\x36\n\x05\x66ield\x18\x01 \x03(\x0b\x32\'.injective_explorer_rpc.WasmCw20Balance\"\x9e\x01\n\x0fWasmCw20Balance\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\x12\x12;\n\rcw20_metadata\x18\x05 \x01(\x0b\x32$.injective_explorer_rpc.Cw20Metadata\"&\n\x0fRelayersRequest\x12\x13\n\x0bmarket_i_ds\x18\x01 \x03(\t\"I\n\x10RelayersResponse\x12\x35\n\x05\x66ield\x18\x01 \x03(\x0b\x32&.injective_explorer_rpc.RelayerMarkets\"V\n\x0eRelayerMarkets\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x31\n\x08relayers\x18\x02 \x03(\x0b\x32\x1f.injective_explorer_rpc.Relayer\"$\n\x07Relayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x63ta\x18\x02 \x01(\t\"\xd6\x01\n\x17GetBankTransfersRequest\x12\x0f\n\x07senders\x18\x01 \x03(\t\x12\x12\n\nrecipients\x18\x02 \x03(\t\x12!\n\x19is_community_pool_related\x18\x03 \x01(\x08\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x0f\n\x07\x61\x64\x64ress\x18\x08 \x03(\t\x12\x10\n\x08per_page\x18\t \x01(\x11\x12\r\n\x05token\x18\n \x01(\t\"~\n\x18GetBankTransfersResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.BankTransfer\"\x8f\x01\n\x0c\x42\x61nkTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\trecipient\x18\x02 \x01(\t\x12-\n\x07\x61mounts\x18\x03 \x03(\x0b\x32\x1c.injective_explorer_rpc.Coin\x12\x14\n\x0c\x62lock_number\x18\x04 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x05 \x01(\t\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x12\n\x10StreamTxsRequest\"\xc8\x01\n\x11StreamTxsResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x11\n\tcodespace\x18\x05 \x01(\t\x12\x10\n\x08messages\x18\x06 \x01(\t\x12\x11\n\ttx_number\x18\x07 \x01(\x04\x12\x11\n\terror_log\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\r\x12\x11\n\tclaim_ids\x18\n \x03(\x12\"\x15\n\x13StreamBlocksRequest\"\xdf\x01\n\x14StreamBlocksResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x10\n\x08proposer\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x12\n\nblock_hash\x18\x04 \x01(\t\x12\x13\n\x0bparent_hash\x18\x05 \x01(\t\x12\x17\n\x0fnum_pre_commits\x18\x06 \x01(\x12\x12\x0f\n\x07num_txs\x18\x07 \x01(\x12\x12.\n\x03txs\x18\x08 \x03(\x0b\x32!.injective_explorer_rpc.TxDataRPC\x12\x11\n\ttimestamp\x18\t \x01(\t2\xcf\x12\n\x14InjectiveExplorerRPC\x12l\n\rGetAccountTxs\x12,.injective_explorer_rpc.GetAccountTxsRequest\x1a-.injective_explorer_rpc.GetAccountTxsResponse\x12o\n\x0eGetContractTxs\x12-.injective_explorer_rpc.GetContractTxsRequest\x1a..injective_explorer_rpc.GetContractTxsResponse\x12`\n\tGetBlocks\x12(.injective_explorer_rpc.GetBlocksRequest\x1a).injective_explorer_rpc.GetBlocksResponse\x12]\n\x08GetBlock\x12\'.injective_explorer_rpc.GetBlockRequest\x1a(.injective_explorer_rpc.GetBlockResponse\x12l\n\rGetValidators\x12,.injective_explorer_rpc.GetValidatorsRequest\x1a-.injective_explorer_rpc.GetValidatorsResponse\x12i\n\x0cGetValidator\x12+.injective_explorer_rpc.GetValidatorRequest\x1a,.injective_explorer_rpc.GetValidatorResponse\x12{\n\x12GetValidatorUptime\x12\x31.injective_explorer_rpc.GetValidatorUptimeRequest\x1a\x32.injective_explorer_rpc.GetValidatorUptimeResponse\x12W\n\x06GetTxs\x12%.injective_explorer_rpc.GetTxsRequest\x1a&.injective_explorer_rpc.GetTxsResponse\x12l\n\rGetTxByTxHash\x12,.injective_explorer_rpc.GetTxByTxHashRequest\x1a-.injective_explorer_rpc.GetTxByTxHashResponse\x12{\n\x12GetPeggyDepositTxs\x12\x31.injective_explorer_rpc.GetPeggyDepositTxsRequest\x1a\x32.injective_explorer_rpc.GetPeggyDepositTxsResponse\x12\x84\x01\n\x15GetPeggyWithdrawalTxs\x12\x34.injective_explorer_rpc.GetPeggyWithdrawalTxsRequest\x1a\x35.injective_explorer_rpc.GetPeggyWithdrawalTxsResponse\x12x\n\x11GetIBCTransferTxs\x12\x30.injective_explorer_rpc.GetIBCTransferTxsRequest\x1a\x31.injective_explorer_rpc.GetIBCTransferTxsResponse\x12i\n\x0cGetWasmCodes\x12+.injective_explorer_rpc.GetWasmCodesRequest\x1a,.injective_explorer_rpc.GetWasmCodesResponse\x12r\n\x0fGetWasmCodeByID\x12..injective_explorer_rpc.GetWasmCodeByIDRequest\x1a/.injective_explorer_rpc.GetWasmCodeByIDResponse\x12u\n\x10GetWasmContracts\x12/.injective_explorer_rpc.GetWasmContractsRequest\x1a\x30.injective_explorer_rpc.GetWasmContractsResponse\x12\x8d\x01\n\x18GetWasmContractByAddress\x12\x37.injective_explorer_rpc.GetWasmContractByAddressRequest\x1a\x38.injective_explorer_rpc.GetWasmContractByAddressResponse\x12o\n\x0eGetCw20Balance\x12-.injective_explorer_rpc.GetCw20BalanceRequest\x1a..injective_explorer_rpc.GetCw20BalanceResponse\x12]\n\x08Relayers\x12\'.injective_explorer_rpc.RelayersRequest\x1a(.injective_explorer_rpc.RelayersResponse\x12u\n\x10GetBankTransfers\x12/.injective_explorer_rpc.GetBankTransfersRequest\x1a\x30.injective_explorer_rpc.GetBankTransfersResponse\x12\x62\n\tStreamTxs\x12(.injective_explorer_rpc.StreamTxsRequest\x1a).injective_explorer_rpc.StreamTxsResponse0\x01\x12k\n\x0cStreamBlocks\x12+.injective_explorer_rpc.StreamBlocksRequest\x1a,.injective_explorer_rpc.StreamBlocksResponse0\x01\x42\x1bZ\x19/injective_explorer_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_explorer_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\031/injective_explorer_rpcpb'
  _EVENT_ATTRIBUTESENTRY._options = None
  _EVENT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _globals['_GETACCOUNTTXSREQUEST']._serialized_start=66
  _globals['_GETACCOUNTTXSREQUEST']._serialized_end=289
  _globals['_GETACCOUNTTXSRESPONSE']._serialized_start=291
  _globals['_GETACCOUNTTXSRESPONSE']._serialized_end=414
  _globals['_PAGING']._serialized_start=416
  _globals['_PAGING']._serialized_end=508
  _globals['_TXDETAILDATA']._serialized_start=511
  _globals['_TXDETAILDATA']._serialized_end=998
  _globals['_GASFEE']._serialized_start=1000
  _globals['_GASFEE']._serialized_end=1111
  _globals['_COSMOSCOIN']._serialized_start=1113
  _globals['_COSMOSCOIN']._serialized_end=1156
  _globals['_EVENT']._serialized_start=1159
  _globals['_EVENT']._serialized_end=1298
  _globals['_EVENT_ATTRIBUTESENTRY']._serialized_start=1249
  _globals['_EVENT_ATTRIBUTESENTRY']._serialized_end=1298
  _globals['_SIGNATURE']._serialized_start=1300
  _globals['_SIGNATURE']._serialized_end=1381
  _globals['_GETCONTRACTTXSREQUEST']._serialized_start=1383
  _globals['_GETCONTRACTTXSREQUEST']._serialized_end=1492
  _globals['_GETCONTRACTTXSRESPONSE']._serialized_start=1494
  _globals['_GETCONTRACTTXSRESPONSE']._serialized_end=1618
  _globals['_GETBLOCKSREQUEST']._serialized_start=1620
  _globals['_GETBLOCKSREQUEST']._serialized_end=1684
  _globals['_GETBLOCKSRESPONSE']._serialized_start=1686
  _globals['_GETBLOCKSRESPONSE']._serialized_end=1802
  _globals['_BLOCKINFO']._serialized_start=1805
  _globals['_BLOCKINFO']._serialized_end=2017
  _globals['_TXDATARPC']._serialized_start=2020
  _globals['_TXDATARPC']._serialized_end=2212
  _globals['_GETBLOCKREQUEST']._serialized_start=2214
  _globals['_GETBLOCKREQUEST']._serialized_end=2243
  _globals['_GETBLOCKRESPONSE']._serialized_start=2245
  _globals['_GETBLOCKRESPONSE']._serialized_end=2345
  _globals['_BLOCKDETAILINFO']._serialized_start=2348
  _globals['_BLOCKDETAILINFO']._serialized_end=2582
  _globals['_TXDATA']._serialized_start=2585
  _globals['_TXDATA']._serialized_end=2810
  _globals['_GETVALIDATORSREQUEST']._serialized_start=2812
  _globals['_GETVALIDATORSREQUEST']._serialized_end=2834
  _globals['_GETVALIDATORSRESPONSE']._serialized_start=2836
  _globals['_GETVALIDATORSRESPONSE']._serialized_end=2935
  _globals['_VALIDATOR']._serialized_start=2938
  _globals['_VALIDATOR']._serialized_end=3581
  _globals['_VALIDATORDESCRIPTION']._serialized_start=3584
  _globals['_VALIDATORDESCRIPTION']._serialized_end=3720
  _globals['_VALIDATORUPTIME']._serialized_start=3722
  _globals['_VALIDATORUPTIME']._serialized_end=3777
  _globals['_SLASHINGEVENT']._serialized_start=3780
  _globals['_SLASHINGEVENT']._serialized_end=3929
  _globals['_GETVALIDATORREQUEST']._serialized_start=3931
  _globals['_GETVALIDATORREQUEST']._serialized_end=3969
  _globals['_GETVALIDATORRESPONSE']._serialized_start=3971
  _globals['_GETVALIDATORRESPONSE']._serialized_end=4069
  _globals['_GETVALIDATORUPTIMEREQUEST']._serialized_start=4071
  _globals['_GETVALIDATORUPTIMEREQUEST']._serialized_end=4115
  _globals['_GETVALIDATORUPTIMERESPONSE']._serialized_start=4117
  _globals['_GETVALIDATORUPTIMERESPONSE']._serialized_end=4227
  _globals['_GETTXSREQUEST']._serialized_start=4230
  _globals['_GETTXSREQUEST']._serialized_end=4429
  _globals['_GETTXSRESPONSE']._serialized_start=4431
  _globals['_GETTXSRESPONSE']._serialized_end=4541
  _globals['_GETTXBYTXHASHREQUEST']._serialized_start=4543
  _globals['_GETTXBYTXHASHREQUEST']._serialized_end=4579
  _globals['_GETTXBYTXHASHRESPONSE']._serialized_start=4581
  _globals['_GETTXBYTXHASHRESPONSE']._serialized_end=4683
  _globals['_GETPEGGYDEPOSITTXSREQUEST']._serialized_start=4685
  _globals['_GETPEGGYDEPOSITTXSREQUEST']._serialized_end=4775
  _globals['_GETPEGGYDEPOSITTXSRESPONSE']._serialized_start=4777
  _globals['_GETPEGGYDEPOSITTXSRESPONSE']._serialized_end=4860
  _globals['_PEGGYDEPOSITTX']._serialized_start=4863
  _globals['_PEGGYDEPOSITTX']._serialized_end=5111
  _globals['_GETPEGGYWITHDRAWALTXSREQUEST']._serialized_start=5113
  _globals['_GETPEGGYWITHDRAWALTXSREQUEST']._serialized_end=5206
  _globals['_GETPEGGYWITHDRAWALTXSRESPONSE']._serialized_start=5208
  _globals['_GETPEGGYWITHDRAWALTXSRESPONSE']._serialized_end=5297
  _globals['_PEGGYWITHDRAWALTX']._serialized_start=5300
  _globals['_PEGGYWITHDRAWALTX']._serialized_end=5639
  _globals['_GETIBCTRANSFERTXSREQUEST']._serialized_start=5642
  _globals['_GETIBCTRANSFERTXSREQUEST']._serialized_end=5811
  _globals['_GETIBCTRANSFERTXSRESPONSE']._serialized_start=5813
  _globals['_GETIBCTRANSFERTXSRESPONSE']._serialized_end=5894
  _globals['_IBCTRANSFERTX']._serialized_start=5897
  _globals['_IBCTRANSFERTX']._serialized_end=6245
  _globals['_GETWASMCODESREQUEST']._serialized_start=6247
  _globals['_GETWASMCODESREQUEST']._serialized_end=6323
  _globals['_GETWASMCODESRESPONSE']._serialized_start=6325
  _globals['_GETWASMCODESRESPONSE']._serialized_end=6443
  _globals['_WASMCODE']._serialized_start=6446
  _globals['_WASMCODE']._serialized_end=6787
  _globals['_CHECKSUM']._serialized_start=6789
  _globals['_CHECKSUM']._serialized_end=6832
  _globals['_CONTRACTPERMISSION']._serialized_start=6834
  _globals['_CONTRACTPERMISSION']._serialized_end=6892
  _globals['_GETWASMCODEBYIDREQUEST']._serialized_start=6894
  _globals['_GETWASMCODEBYIDREQUEST']._serialized_end=6935
  _globals['_GETWASMCODEBYIDRESPONSE']._serialized_start=6938
  _globals['_GETWASMCODEBYIDRESPONSE']._serialized_end=7294
  _globals['_GETWASMCONTRACTSREQUEST']._serialized_start=7297
  _globals['_GETWASMCONTRACTSREQUEST']._serialized_end=7444
  _globals['_GETWASMCONTRACTSRESPONSE']._serialized_start=7446
  _globals['_GETWASMCONTRACTSRESPONSE']._serialized_end=7572
  _globals['_WASMCONTRACT']._serialized_start=7575
  _globals['_WASMCONTRACT']._serialized_end=8002
  _globals['_CONTRACTFUND']._serialized_start=8004
  _globals['_CONTRACTFUND']._serialized_end=8049
  _globals['_CW20METADATA']._serialized_start=8052
  _globals['_CW20METADATA']._serialized_end=8192
  _globals['_CW20TOKENINFO']._serialized_start=8194
  _globals['_CW20TOKENINFO']._serialized_end=8279
  _globals['_CW20MARKETINGINFO']._serialized_start=8281
  _globals['_CW20MARKETINGINFO']._serialized_end=8371
  _globals['_GETWASMCONTRACTBYADDRESSREQUEST']._serialized_start=8373
  _globals['_GETWASMCONTRACTBYADDRESSREQUEST']._serialized_end=8432
  _globals['_GETWASMCONTRACTBYADDRESSRESPONSE']._serialized_start=8435
  _globals['_GETWASMCONTRACTBYADDRESSRESPONSE']._serialized_end=8882
  _globals['_GETCW20BALANCEREQUEST']._serialized_start=8884
  _globals['_GETCW20BALANCEREQUEST']._serialized_end=8939
  _globals['_GETCW20BALANCERESPONSE']._serialized_start=8941
  _globals['_GETCW20BALANCERESPONSE']._serialized_end=9021
  _globals['_WASMCW20BALANCE']._serialized_start=9024
  _globals['_WASMCW20BALANCE']._serialized_end=9182
  _globals['_RELAYERSREQUEST']._serialized_start=9184
  _globals['_RELAYERSREQUEST']._serialized_end=9222
  _globals['_RELAYERSRESPONSE']._serialized_start=9224
  _globals['_RELAYERSRESPONSE']._serialized_end=9297
  _globals['_RELAYERMARKETS']._serialized_start=9299
  _globals['_RELAYERMARKETS']._serialized_end=9385
  _globals['_RELAYER']._serialized_start=9387
  _globals['_RELAYER']._serialized_end=9423
  _globals['_GETBANKTRANSFERSREQUEST']._serialized_start=9426
  _globals['_GETBANKTRANSFERSREQUEST']._serialized_end=9640
  _globals['_GETBANKTRANSFERSRESPONSE']._serialized_start=9642
  _globals['_GETBANKTRANSFERSRESPONSE']._serialized_end=9768
  _globals['_BANKTRANSFER']._serialized_start=9771
  _globals['_BANKTRANSFER']._serialized_end=9914
  _globals['_COIN']._serialized_start=9916
  _globals['_COIN']._serialized_end=9953
  _globals['_STREAMTXSREQUEST']._serialized_start=9955
  _globals['_STREAMTXSREQUEST']._serialized_end=9973
  _globals['_STREAMTXSRESPONSE']._serialized_start=9976
  _globals['_STREAMTXSRESPONSE']._serialized_end=10176
  _globals['_STREAMBLOCKSREQUEST']._serialized_start=10178
  _globals['_STREAMBLOCKSREQUEST']._serialized_end=10199
  _globals['_STREAMBLOCKSRESPONSE']._serialized_start=10202
  _globals['_STREAMBLOCKSRESPONSE']._serialized_end=10425
  _globals['_INJECTIVEEXPLORERRPC']._serialized_start=10428
  _globals['_INJECTIVEEXPLORERRPC']._serialized_end=12811
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/batch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/peggy/v1/batch.proto\x12\x12injective.peggy.v1\x1a$injective/peggy/v1/attestation.proto\"\xa2\x01\n\x0fOutgoingTxBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x02 \x01(\x04\x12<\n\x0ctransactions\x18\x03 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\r\n\x05\x62lock\x18\x05 \x01(\x04\"\xae\x01\n\x12OutgoingTransferTx\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65st_address\x18\x03 \x01(\t\x12\x33\n\x0b\x65rc20_token\x18\x04 \x01(\x0b\x32\x1e.injective.peggy.v1.ERC20Token\x12\x31\n\terc20_fee\x18\x05 \x01(\x0b\x32\x1e.injective.peggy.v1.ERC20TokenBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.batch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _globals['_OUTGOINGTXBATCH']._serialized_start=93
  _globals['_OUTGOINGTXBATCH']._serialized_end=255
  _globals['_OUTGOINGTRANSFERTX']._serialized_start=258
  _globals['_OUTGOINGTRANSFERTX']._serialized_end=432
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/bank.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/bank/v1beta1/bank.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x85\x01\n\x06Params\x12:\n\x0csend_enabled\x18\x01 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabledB\x02\x18\x01\x12\x1c\n\x14\x64\x65\x66\x61ult_send_enabled\x18\x02 \x01(\x08:!\x98\xa0\x1f\x00\x8a\xe7\xb0*\x18\x63osmos-sdk/x/bank/Params\"7\n\x0bSendEnabled\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"\xa9\x01\n\x05Input\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12_\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:\x14\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x07\x61\x64\x64ress\"\x9e\x01\n\x06Output\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12_\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x94\x01\n\x06Supply\x12_\n\x05total\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:)\x18\x01\x88\xa0\x1f\x00\xe8\xa0\x1f\x01\xca\xb4-\x1b\x63osmos.bank.v1beta1.SupplyI\"=\n\tDenomUnit\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08\x65xponent\x18\x02 \x01(\r\x12\x0f\n\x07\x61liases\x18\x03 \x03(\t\"\xc6\x01\n\x08Metadata\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x33\n\x0b\x64\x65nom_units\x18\x02 \x03(\x0b\x32\x1e.cosmos.bank.v1beta1.DenomUnit\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\x0f\n\x07\x64isplay\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06symbol\x18\x06 \x01(\t\x12\x14\n\x03uri\x18\x07 \x01(\tB\x07\xe2\xde\x1f\x03URI\x12\x1d\n\x08uri_hash\x18\x08 \x01(\tB\x0b\xe2\xde\x1f\x07URIHashB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.bank_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _PARAMS.fields_by_name['send_enabled']._options = None
  _PARAMS.fields_by_name['send_enabled']._serialized_options = b'\030\001'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000\212\347\260*\030cosmos-sdk/x/bank/Params'
  _SENDENABLED._options = None
  _SENDENABLED._serialized_options = b'\230\240\037\000\350\240\037\001'
  _INPUT.fields_by_name['address']._options = None
  _INPUT.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _INPUT.fields_by_name['coins']._options = None
  _INPUT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _INPUT._options = None
  _INPUT._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\007address'
  _OUTPUT.fields_by_name['address']._options = None
  _OUTPUT.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _OUTPUT.fields_by_name['coins']._options = None
  _OUTPUT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _OUTPUT._options = None
  _OUTPUT._serialized_options = b'\210\240\037\000\350\240\037\000'
  _SUPPLY.fields_by_name['total']._options = None
  _SUPPLY.fields_by_name['total']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _SUPPLY._options = None
  _SUPPLY._serialized_options = b'\030\001\210\240\037\000\350\240\037\001\312\264-\033cosmos.bank.v1beta1.SupplyI'
  _METADATA.fields_by_name['uri']._options = None
  _METADATA.fields_by_name['uri']._serialized_options = b'\342\336\037\003URI'
  _METADATA.fields_by_name['uri_hash']._options = None
  _METADATA.fields_by_name['uri_hash']._serialized_options = b'\342\336\037\007URIHash'
  _globals['_PARAMS']._serialized_start=181
  _globals['_PARAMS']._serialized_end=314
  _globals['_SENDENABLED']._serialized_start=316
  _globals['_SENDENABLED']._serialized_end=371
  _globals['_INPUT']._serialized_start=374
  _globals['_INPUT']._serialized_end=543
  _globals['_OUTPUT']._serialized_start=546
  _globals['_OUTPUT']._serialized_end=704
  _globals['_SUPPLY']._serialized_start=707
  _globals['_SUPPLY']._serialized_end=855
  _globals['_DENOMUNIT']._serialized_start=857
  _globals['_DENOMUNIT']._serialized_end=918
  _globals['_METADATA']._serialized_start=921
  _globals['_METADATA']._serialized_end=1119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/gov/v1beta1/query.proto\x12\x12\x63osmos.gov.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1c\x63osmos/gov/v1beta1/gov.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"+\n\x14QueryProposalRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"R\n\x15QueryProposalResponse\x12\x39\n\x08proposal\x18\x01 \x01(\x0b\x32\x1c.cosmos.gov.v1beta1.ProposalB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xf0\x01\n\x15QueryProposalsRequest\x12;\n\x0fproposal_status\x18\x01 \x01(\x0e\x32\".cosmos.gov.v1beta1.ProposalStatus\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\tdepositor\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x91\x01\n\x16QueryProposalsResponse\x12:\n\tproposals\x18\x01 \x03(\x0b\x32\x1c.cosmos.gov.v1beta1.ProposalB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x10QueryVoteRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"F\n\x11QueryVoteResponse\x12\x31\n\x04vote\x18\x01 \x01(\x0b\x32\x18.cosmos.gov.v1beta1.VoteB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"d\n\x11QueryVotesRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x85\x01\n\x12QueryVotesResponse\x12\x32\n\x05votes\x18\x01 \x03(\x0b\x32\x18.cosmos.gov.v1beta1.VoteB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\")\n\x12QueryParamsRequest\x12\x13\n\x0bparams_type\x18\x01 \x01(\t\"\xe1\x01\n\x13QueryParamsResponse\x12\x42\n\rvoting_params\x18\x01 \x01(\x0b\x32 .cosmos.gov.v1beta1.VotingParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x44\n\x0e\x64\x65posit_params\x18\x02 \x01(\x0b\x32!.cosmos.gov.v1beta1.DepositParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12@\n\x0ctally_params\x18\x03 \x01(\x0b\x32\x1f.cosmos.gov.v1beta1.TallyParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"a\n\x13QueryDepositRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"O\n\x14QueryDepositResponse\x12\x37\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\x1b.cosmos.gov.v1beta1.DepositB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"g\n\x14QueryDepositsRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8e\x01\n\x15QueryDepositsResponse\x12\x38\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32\x1b.cosmos.gov.v1beta1.DepositB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\".\n\x17QueryTallyResultRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"U\n\x18QueryTallyResultResponse\x12\x39\n\x05tally\x18\x01 \x01(\x0b\x32\x1f.cosmos.gov.v1beta1.TallyResultB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xd4\t\n\x05Query\x12\x94\x01\n\x08Proposal\x12(.cosmos.gov.v1beta1.QueryProposalRequest\x1a).cosmos.gov.v1beta1.QueryProposalResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/gov/v1beta1/proposals/{proposal_id}\x12\x89\x01\n\tProposals\x12).cosmos.gov.v1beta1.QueryProposalsRequest\x1a*.cosmos.gov.v1beta1.QueryProposalsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/gov/v1beta1/proposals\x12\x96\x01\n\x04Vote\x12$.cosmos.gov.v1beta1.QueryVoteRequest\x1a%.cosmos.gov.v1beta1.QueryVoteResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/cosmos/gov/v1beta1/proposals/{proposal_id}/votes/{voter}\x12\x91\x01\n\x05Votes\x12%.cosmos.gov.v1beta1.QueryVotesRequest\x1a&.cosmos.gov.v1beta1.QueryVotesResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/cosmos/gov/v1beta1/proposals/{proposal_id}/votes\x12\x8b\x01\n\x06Params\x12&.cosmos.gov.v1beta1.QueryParamsRequest\x1a\'.cosmos.gov.v1beta1.QueryParamsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/cosmos/gov/v1beta1/params/{params_type}\x12\xa6\x01\n\x07\x44\x65posit\x12\'.cosmos.gov.v1beta1.QueryDepositRequest\x1a(.cosmos.gov.v1beta1.QueryDepositResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits/{depositor}\x12\x9d\x01\n\x08\x44\x65posits\x12(.cosmos.gov.v1beta1.QueryDepositsRequest\x1a).cosmos.gov.v1beta1.QueryDepositsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits\x12\xa3\x01\n\x0bTallyResult\x12+.cosmos.gov.v1beta1.QueryTallyResultRequest\x1a,.cosmos.gov.v1beta1.QueryTallyResultResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/cosmos/gov/v1beta1/proposals/{proposal_id}/tallyB2Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1'
  _QUERYPROPOSALRESPONSE.fields_by_name['proposal']._options = None
  _QUERYPROPOSALRESPONSE.fields_by_name['proposal']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPROPOSALSREQUEST.fields_by_name['voter']._options = None
  _QUERYPROPOSALSREQUEST.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYPROPOSALSREQUEST.fields_by_name['depositor']._options = None
  _QUERYPROPOSALSREQUEST.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYPROPOSALSREQUEST._options = None
  _QUERYPROPOSALSREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYPROPOSALSRESPONSE.fields_by_name['proposals']._options = None
  _QUERYPROPOSALSRESPONSE.fields_by_name['proposals']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYVOTEREQUEST.fields_by_name['voter']._options = None
  _QUERYVOTEREQUEST.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVOTEREQUEST._options = None
  _QUERYVOTEREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYVOTERESPONSE.fields_by_name['vote']._options = None
  _QUERYVOTERESPONSE.fields_by_name['vote']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYVOTESRESPONSE.fields_by_name['votes']._options = None
  _QUERYVOTESRESPONSE.fields_by_name['votes']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPARAMSRESPONSE.fields_by_name['voting_params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['voting_params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPARAMSRESPONSE.fields_by_name['deposit_params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['deposit_params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPARAMSRESPONSE.fields_by_name['tally_params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['tally_params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDEPOSITREQUEST.fields_by_name['depositor']._options = None
  _QUERYDEPOSITREQUEST.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDEPOSITREQUEST._options = None
  _QUERYDEPOSITREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._options = None
  _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._options = None
  _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYTALLYRESULTRESPONSE.fields_by_name['tally']._options = None
  _QUERYTALLYRESULTRESPONSE.fields_by_name['tally']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERY.methods_by_name['Proposal']._options = None
  _QUERY.methods_by_name['Proposal']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/gov/v1beta1/proposals/{proposal_id}'
  _QUERY.methods_by_name['Proposals']._options = None
  _QUERY.methods_by_name['Proposals']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/gov/v1beta1/proposals'
  _QUERY.methods_by_name['Vote']._options = None
  _QUERY.methods_by_name['Vote']._serialized_options = b'\202\323\344\223\002;\0229/cosmos/gov/v1beta1/proposals/{proposal_id}/votes/{voter}'
  _QUERY.methods_by_name['Votes']._options = None
  _QUERY.methods_by_name['Votes']._serialized_options = b'\202\323\344\223\0023\0221/cosmos/gov/v1beta1/proposals/{proposal_id}/votes'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002*\022(/cosmos/gov/v1beta1/params/{params_type}'
  _QUERY.methods_by_name['Deposit']._options = None
  _QUERY.methods_by_name['Deposit']._serialized_options = b'\202\323\344\223\002B\022@/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits/{depositor}'
  _QUERY.methods_by_name['Deposits']._options = None
  _QUERY.methods_by_name['Deposits']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/gov/v1beta1/proposals/{proposal_id}/deposits'
  _QUERY.methods_by_name['TallyResult']._options = None
  _QUERY.methods_by_name['TallyResult']._serialized_options = b'\202\323\344\223\0023\0221/cosmos/gov/v1beta1/proposals/{proposal_id}/tally'
  _globals['_QUERYPROPOSALREQUEST']._serialized_start=226
  _globals['_QUERYPROPOSALREQUEST']._serialized_end=269
  _globals['_QUERYPROPOSALRESPONSE']._serialized_start=271
  _globals['_QUERYPROPOSALRESPONSE']._serialized_end=353
  _globals['_QUERYPROPOSALSREQUEST']._serialized_start=356
  _globals['_QUERYPROPOSALSREQUEST']._serialized_end=596
  _globals['_QUERYPROPOSALSRESPONSE']._serialized_start=599
  _globals['_QUERYPROPOSALSRESPONSE']._serialized_end=744
  _globals['_QUERYVOTEREQUEST']._serialized_start=746
  _globals['_QUERYVOTEREQUEST']._serialized_end=836
  _globals['_QUERYVOTERESPONSE']._serialized_start=838
  _globals['_QUERYVOTERESPONSE']._serialized_end=908
  _globals['_QUERYVOTESREQUEST']._serialized_start=910
  _globals['_QUERYVOTESREQUEST']._serialized_end=1010
  _globals['_QUERYVOTESRESPONSE']._serialized_start=1013
  _globals['_QUERYVOTESRESPONSE']._serialized_end=1146
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1148
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1189
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1192
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1417
  _globals['_QUERYDEPOSITREQUEST']._serialized_start=1419
  _globals['_QUERYDEPOSITREQUEST']._serialized_end=1516
  _globals['_QUERYDEPOSITRESPONSE']._serialized_start=1518
  _globals['_QUERYDEPOSITRESPONSE']._serialized_end=1597
  _globals['_QUERYDEPOSITSREQUEST']._serialized_start=1599
  _globals['_QUERYDEPOSITSREQUEST']._serialized_end=1702
  _globals['_QUERYDEPOSITSRESPONSE']._serialized_start=1705
  _globals['_QUERYDEPOSITSRESPONSE']._serialized_end=1847
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_start=1849
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_end=1895
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_start=1897
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_end=1982
  _globals['_QUERY']._serialized_start=1985
  _globals['_QUERY']._serialized_end=3221
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2
from injective.tokenfactory.v1beta1 import params_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_params__pb2
from injective.tokenfactory.v1beta1 import genesis_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*injective/tokenfactory/v1beta1/query.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\x1a+injective/tokenfactory/v1beta1/params.proto\x1a,injective/tokenfactory/v1beta1/genesis.proto\"\x14\n\x12QueryParamsRequest\"S\n\x13QueryParamsResponse\x12<\n\x06params\x18\x01 \x01(\x0b\x32&.injective.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"p\n\"QueryDenomAuthorityMetadataRequest\x12!\n\x07\x63reator\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\x12\'\n\tsub_denom\x18\x02 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"sub_denom\"\"\x9c\x01\n#QueryDenomAuthorityMetadataResponse\x12u\n\x12\x61uthority_metadata\x18\x01 \x01(\x0b\x32\x36.injective.tokenfactory.v1beta1.DenomAuthorityMetadataB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"authority_metadata\"\"D\n\x1dQueryDenomsFromCreatorRequest\x12#\n\x07\x63reator\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"creator\"\"C\n\x1eQueryDenomsFromCreatorResponse\x12!\n\x06\x64\x65noms\x18\x01 \x03(\tB\x11\xf2\xde\x1f\ryaml:\"denoms\"\"\x19\n\x17QueryModuleStateRequest\"W\n\x18QueryModuleStateResponse\x12;\n\x05state\x18\x01 \x01(\x0b\x32,.injective.tokenfactory.v1beta1.GenesisState2\xc9\x06\n\x05Query\x12\xa1\x01\n\x06Params\x12\x32.injective.tokenfactory.v1beta1.QueryParamsRequest\x1a\x33.injective.tokenfactory.v1beta1.QueryParamsResponse\".\x82\xd3\xe4\x93\x02(\x12&/injective/tokenfactory/v1beta1/params\x12\xfa\x01\n\x16\x44\x65nomAuthorityMetadata\x12\x42.injective.tokenfactory.v1beta1.QueryDenomAuthorityMetadataRequest\x1a\x43.injective.tokenfactory.v1beta1.QueryDenomAuthorityMetadataResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/injective/tokenfactory/v1beta1/denoms/{creator}/{sub_denom}/authority_metadata\x12\xd9\x01\n\x11\x44\x65nomsFromCreator\x12=.injective.tokenfactory.v1beta1.QueryDenomsFromCreatorRequest\x1a>.injective.tokenfactory.v1beta1.QueryDenomsFromCreatorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/tokenfactory/v1beta1/denoms_from_creator/{creator}\x12\xc2\x01\n\x17TokenfactoryModuleState\x12\x37.injective.tokenfactory.v1beta1.QueryModuleStateRequest\x1a\x38.injective.tokenfactory.v1beta1.QueryModuleStateResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/tokenfactory/v1beta1/module_stateBTZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYDENOMAUTHORITYMETADATAREQUEST.fields_by_name['creator']._options = None
  _QUERYDENOMAUTHORITYMETADATAREQUEST.fields_by_name['creator']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _QUERYDENOMAUTHORITYMETADATAREQUEST.fields_by_name['sub_denom']._options = None
  _QUERYDENOMAUTHORITYMETADATAREQUEST.fields_by_name['sub_denom']._serialized_options = b'\362\336\037\020yaml:\"sub_denom\"'
  _QUERYDENOMAUTHORITYMETADATARESPONSE.fields_by_name['authority_metadata']._options = None
  _QUERYDENOMAUTHORITYMETADATARESPONSE.fields_by_name['authority_metadata']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"authority_metadata\"'
  _QUERYDENOMSFROMCREATORREQUEST.fields_by_name['creator']._options = None
  _QUERYDENOMSFROMCREATORREQUEST.fields_by_name['creator']._serialized_options = b'\362\336\037\016yaml:\"creator\"'
  _QUERYDENOMSFROMCREATORRESPONSE.fields_by_name['denoms']._options = None
  _QUERYDENOMSFROMCREATORRESPONSE.fields_by_name['denoms']._serialized_options = b'\362\336\037\ryaml:\"denoms\"'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002(\022&/injective/tokenfactory/v1beta1/params'
  _QUERY.methods_by_name['DenomAuthorityMetadata']._options = None
  _QUERY.methods_by_name['DenomAuthorityMetadata']._serialized_options = b'\202\323\344\223\002Q\022O/injective/tokenfactory/v1beta1/denoms/{creator}/{sub_denom}/authority_metadata'
  _QUERY.methods_by_name['DenomsFromCreator']._options = None
  _QUERY.methods_by_name['DenomsFromCreator']._serialized_options = b'\202\323\344\223\002?\022=/injective/tokenfactory/v1beta1/denoms_from_creator/{creator}'
  _QUERY.methods_by_name['TokenfactoryModuleState']._options = None
  _QUERY.methods_by_name['TokenfactoryModuleState']._serialized_options = b'\202\323\344\223\002.\022,/injective/tokenfactory/v1beta1/module_state'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=321
  _globals['_QUERYPARAMSREQUEST']._serialized_end=341
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=343
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=426
  _globals['_QUERYDENOMAUTHORITYMETADATAREQUEST']._serialized_start=428
  _globals['_QUERYDENOMAUTHORITYMETADATAREQUEST']._serialized_end=540
  _globals['_QUERYDENOMAUTHORITYMETADATARESPONSE']._serialized_start=543
  _globals['_QUERYDENOMAUTHORITYMETADATARESPONSE']._serialized_end=699
  _globals['_QUERYDENOMSFROMCREATORREQUEST']._serialized_start=701
  _globals['_QUERYDENOMSFROMCREATORREQUEST']._serialized_end=769
  _globals['_QUERYDENOMSFROMCREATORRESPONSE']._serialized_start=771
  _globals['_QUERYDENOMSFROMCREATORRESPONSE']._serialized_end=838
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=840
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=865
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=867
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=954
  _globals['_QUERY']._serialized_start=957
  _globals['_QUERY']._serialized_end=1798
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/localhost/v2/localhost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ibc/lightclients/localhost/v2/localhost.proto\x12\x1dibc.lightclients.localhost.v2\x1a\x1fibc/core/client/v1/client.proto\x1a\x14gogoproto/gogo.proto\"L\n\x0b\x43lientState\x12\x37\n\rlatest_height\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\x42JZHgithub.com/cosmos/ibc-go/v7/modules/light-clients/09-localhost;localhostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.localhost.v2.localhost_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZHgithub.com/cosmos/ibc-go/v7/modules/light-clients/09-localhost;localhost'
  _CLIENTSTATE.fields_by_name['latest_height']._options = None
  _CLIENTSTATE.fields_by_name['latest_height']._serialized_options = b'\310\336\037\000'
  _CLIENTSTATE._options = None
  _CLIENTSTATE._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATE']._serialized_start=135
  _globals['_CLIENTSTATE']._serialized_end=211
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from injective.tokenfactory.v1beta1 import params_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/tokenfactory/v1beta1/tx.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a+injective/tokenfactory/v1beta1/params.proto\"\xa9\x01\n\x0eMsgCreateDenom\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12%\n\x08subdenom\x18\x02 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"subdenom\"\x12\x1d\n\x04name\x18\x03 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"name\"\x12!\n\x06symbol\x18\x04 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"symbol\":\x0b\x82\xe7\xb0*\x06sender\"M\n\x16MsgCreateDenomResponse\x12\x33\n\x0fnew_token_denom\x18\x01 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_token_denom\"\"{\n\x07MsgMint\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12@\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:\"amount\":\x0b\x82\xe7\xb0*\x06sender\"\x11\n\x0fMsgMintResponse\"{\n\x07MsgBurn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12@\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:\"amount\":\x0b\x82\xe7\xb0*\x06sender\"\x11\n\x0fMsgBurnResponse\"\x8a\x01\n\x0eMsgChangeAdmin\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12\x1f\n\x05\x64\x65nom\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\x12\'\n\tnew_admin\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"new_admin\":\x0b\x82\xe7\xb0*\x06sender\"\x18\n\x16MsgChangeAdminResponse\"\x8f\x01\n\x13MsgSetDenomMetadata\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12H\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x17\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"metadata\":\x0b\x82\xe7\xb0*\x06sender\"\x1d\n\x1bMsgSetDenomMetadataResponse\"\x8c\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x06params\x18\x02 \x01(\x0b\x32&.injective.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xb8\x05\n\x03Msg\x12u\n\x0b\x43reateDenom\x12..injective.tokenfactory.v1beta1.MsgCreateDenom\x1a\x36.injective.tokenfactory.v1beta1.MsgCreateDenomResponse\x12`\n\x04Mint\x12\'.injective.tokenfactory.v1beta1.MsgMint\x1a/.injective.tokenfactory.v1beta1.MsgMintResponse\x12`\n\x04\x42urn\x12\'.injective.tokenfactory.v1beta1.MsgBurn\x1a/.injective.tokenfactory.v1beta1.MsgBurnResponse\x12u\n\x0b\x43hangeAdmin\x12..injective.tokenfactory.v1beta1.MsgChangeAdmin\x1a\x36.injective.tokenfactory.v1beta1.MsgChangeAdminResponse\x12\x84\x01\n\x10SetDenomMetadata\x12\x33.injective.tokenfactory.v1beta1.MsgSetDenomMetadata\x1a;.injective.tokenfactory.v1beta1.MsgSetDenomMetadataResponse\x12x\n\x0cUpdateParams\x12/.injective.tokenfactory.v1beta1.MsgUpdateParams\x1a\x37.injective.tokenfactory.v1beta1.MsgUpdateParamsResponseBTZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types'
  _MSGCREATEDENOM.fields_by_name['sender']._options = None
  _MSGCREATEDENOM.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGCREATEDENOM.fields_by_name['subdenom']._options = None
  _MSGCREATEDENOM.fields_by_name['subdenom']._serialized_options = b'\362\336\037\017yaml:\"subdenom\"'
  _MSGCREATEDENOM.fields_by_name['name']._options = None
  _MSGCREATEDENOM.fields_by_name['name']._serialized_options = b'\362\336\037\013yaml:\"name\"'
  _MSGCREATEDENOM.fields_by_name['symbol']._options = None
  _MSGCREATEDENOM.fields_by_name['symbol']._serialized_options = b'\362\336\037\ryaml:\"symbol\"'
  _MSGCREATEDENOM._options = None
  _MSGCREATEDENOM._serialized_options = b'\202\347\260*\006sender'
  _MSGCREATEDENOMRESPONSE.fields_by_name['new_token_denom']._options = None
  _MSGCREATEDENOMRESPONSE.fields_by_name['new_token_denom']._serialized_options = b'\362\336\037\026yaml:\"new_token_denom\"'
  _MSGMINT.fields_by_name['sender']._options = None
  _MSGMINT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGMINT.fields_by_name['amount']._options = None
  _MSGMINT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\362\336\037\ryaml:\"amount\"'
  _MSGMINT._options = None
  _MSGMINT._serialized_options = b'\202\347\260*\006sender'
  _MSGBURN.fields_by_name['sender']._options = None
  _MSGBURN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGBURN.fields_by_name['amount']._options = None
  _MSGBURN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\362\336\037\ryaml:\"amount\"'
  _MSGBURN._options = None
  _MSGBURN._serialized_options = b'\202\347\260*\006sender'
  _MSGCHANGEADMIN.fields_by_name['sender']._options = None
  _MSGCHANGEADMIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGCHANGEADMIN.fields_by_name['denom']._options = None
  _MSGCHANGEADMIN.fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _MSGCHANGEADMIN.fields_by_name['new_admin']._options = None
  _MSGCHANGEADMIN.fields_by_name['new_admin']._serialized_options = b'\362\336\037\020yaml:\"new_admin\"'
  _MSGCHANGEADMIN._options = None
  _MSGCHANGEADMIN._serialized_options = b'\202\347\260*\006sender'
  _MSGSETDENOMMETADATA.fields_by_name['sender']._options = None
  _MSGSETDENOMMETADATA.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSETDENOMMETADATA.fields_by_name['metadata']._options = None
  _MSGSETDENOMMETADATA.fields_by_name['metadata']._serialized_options = b'\310\336\037\000\362\336\037\017yaml:\"metadata\"'
  _MSGSETDENOMMETADATA._options = None
  _MSGSETDENOMMETADATA._serialized_options = b'\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEDENOM']._serialized_start=259
  _globals['_MSGCREATEDENOM']._serialized_end=428
  _globals['_MSGCREATEDENOMRESPONSE']._serialized_start=430
  _globals['_MSGCREATEDENOMRESPONSE']._serialized_end=507
  _globals['_MSGMINT']._serialized_start=509
  _globals['_MSGMINT']._serialized_end=632
  _globals['_MSGMINTRESPONSE']._serialized_start=634
  _globals['_MSGMINTRESPONSE']._serialized_end=651
  _globals['_MSGBURN']._serialized_start=653
  _globals['_MSGBURN']._serialized_end=776
  _globals['_MSGBURNRESPONSE']._serialized_start=778
  _globals['_MSGBURNRESPONSE']._serialized_end=795
  _globals['_MSGCHANGEADMIN']._serialized_start=798
  _globals['_MSGCHANGEADMIN']._serialized_end=936
  _globals['_MSGCHANGEADMINRESPONSE']._serialized_start=938
  _globals['_MSGCHANGEADMINRESPONSE']._serialized_end=962
  _globals['_MSGSETDENOMMETADATA']._serialized_start=965
  _globals['_MSGSETDENOMMETADATA']._serialized_end=1108
  _globals['_MSGSETDENOMMETADATARESPONSE']._serialized_start=1110
  _globals['_MSGSETDENOMMETADATARESPONSE']._serialized_end=1139
  _globals['_MSGUPDATEPARAMS']._serialized_start=1142
  _globals['_MSGUPDATEPARAMS']._serialized_end=1282
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1284
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1309
  _globals['_MSG']._serialized_start=1312
  _globals['_MSG']._serialized_end=2008
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmwasm/wasm/v1/genesis.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x11\x61mino/amino.proto\"\xaa\x02\n\x0cGenesisState\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x43\n\x05\x63odes\x18\x02 \x03(\x0b\x32\x16.cosmwasm.wasm.v1.CodeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x0f\x63odes,omitempty\xa8\xe7\xb0*\x01\x12O\n\tcontracts\x18\x03 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.ContractB \xc8\xde\x1f\x00\xea\xde\x1f\x13\x63ontracts,omitempty\xa8\xe7\xb0*\x01\x12O\n\tsequences\x18\x04 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.SequenceB \xc8\xde\x1f\x00\xea\xde\x1f\x13sequences,omitempty\xa8\xe7\xb0*\x01\"\x81\x01\n\x04\x43ode\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x38\n\tcode_info\x18\x02 \x01(\x0b\x32\x1a.cosmwasm.wasm.v1.CodeInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x12\n\ncode_bytes\x18\x03 \x01(\x0c\x12\x0e\n\x06pinned\x18\x04 \x01(\x08\"\xf8\x01\n\x08\x43ontract\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12@\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12:\n\x0e\x63ontract_state\x18\x03 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12T\n\x15\x63ontract_code_history\x18\x04 \x03(\x0b\x32*.cosmwasm.wasm.v1.ContractCodeHistoryEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"4\n\x08Sequence\x12\x19\n\x06id_key\x18\x01 \x01(\x0c\x42\t\xe2\xde\x1f\x05IDKey\x12\r\n\x05value\x18\x02 \x01(\x04\x42(Z&github.com/CosmWasm/wasmd/x/wasm/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['codes']._options = None
  _GENESISSTATE.fields_by_name['codes']._serialized_options = b'\310\336\037\000\352\336\037\017codes,omitempty\250\347\260*\001'
  _GENESISSTATE.fields_by_name['contracts']._options = None
  _GENESISSTATE.fields_by_name['contracts']._serialized_options = b'\310\336\037\000\352\336\037\023contracts,omitempty\250\347\260*\001'
  _GENESISSTATE.fields_by_name['sequences']._options = None
  _GENESISSTATE.fields_by_name['sequences']._serialized_options = b'\310\336\037\000\352\336\037\023sequences,omitempty\250\347\260*\001'
  _CODE.fields_by_name['code_id']._options = None
  _CODE.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _CODE.fields_by_name['code_info']._options = None
  _CODE.fields_by_name['code_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CONTRACT.fields_by_name['contract_info']._options = None
  _CONTRACT.fields_by_name['contract_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CONTRACT.fields_by_name['contract_state']._options = None
  _CONTRACT.fields_by_name['contract_state']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CONTRACT.fields_by_name['contract_code_history']._options = None
  _CONTRACT.fields_by_name['contract_code_history']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _SEQUENCE.fields_by_name['id_key']._options = None
  _SEQUENCE.fields_by_name['id_key']._serialized_options = b'\342\336\037\005IDKey'
  _globals['_GENESISSTATE']._serialized_start=124
  _globals['_GENESISSTATE']._serialized_end=422
  _globals['_CODE']._serialized_start=425
  _globals['_CODE']._serialized_end=554
  _globals['_CONTRACT']._serialized_start=557
  _globals['_CONTRACT']._serialized_end=805
  _globals['_SEQUENCE']._serialized_start=807
  _globals['_SEQUENCE']._serialized_end=859
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: testpb/test_schema_query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from testpb import test_schema_pb2 as testpb_dot_test__schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etestpb/test_schema_query.proto\x12\x06testpb\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18testpb/test_schema.proto\"?\n\x16GetExampleTableRequest\x12\x0b\n\x03u32\x18\x01 \x01(\r\x12\x0b\n\x03i64\x18\x02 \x01(\x03\x12\x0b\n\x03str\x18\x03 \x01(\t\">\n\x17GetExampleTableResponse\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.testpb.ExampleTable\":\n\x1eGetExampleTableByU64StrRequest\x12\x0b\n\x03u64\x18\x01 \x01(\x04\x12\x0b\n\x03str\x18\x02 \x01(\t\"F\n\x1fGetExampleTableByU64StrResponse\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.testpb.ExampleTable\"\x9e\x07\n\x17ListExampleTableRequest\x12@\n\x0cprefix_query\x18\x01 \x01(\x0b\x32(.testpb.ListExampleTableRequest.IndexKeyH\x00\x12\x41\n\x0brange_query\x18\x02 \x01(\x0b\x32*.testpb.ListExampleTableRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1a\xbc\x04\n\x08IndexKey\x12K\n\ru_32_i_64_str\x18\x01 \x01(\x0b\x32\x32.testpb.ListExampleTableRequest.IndexKey.U32I64StrH\x00\x12\x43\n\x08u_64_str\x18\x02 \x01(\x0b\x32/.testpb.ListExampleTableRequest.IndexKey.U64StrH\x00\x12\x43\n\x08str_u_32\x18\x03 \x01(\x0b\x32/.testpb.ListExampleTableRequest.IndexKey.StrU32H\x00\x12@\n\x06\x62z_str\x18\x04 \x01(\x0b\x32..testpb.ListExampleTableRequest.IndexKey.BzStrH\x00\x1aY\n\tU32I64Str\x12\x10\n\x03u32\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03i64\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03str\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x06\n\x04_u32B\x06\n\x04_i64B\x06\n\x04_str\x1a<\n\x06U64Str\x12\x10\n\x03u64\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x10\n\x03str\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x06\n\x04_u64B\x06\n\x04_str\x1a<\n\x06StrU32\x12\x10\n\x03str\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03u32\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x06\n\x04_strB\x06\n\x04_u32\x1a\x39\n\x05\x42zStr\x12\x0f\n\x02\x62z\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12\x10\n\x03str\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_bzB\x06\n\x04_strB\x05\n\x03key\x1az\n\nRangeQuery\x12\x36\n\x04\x66rom\x18\x01 \x01(\x0b\x32(.testpb.ListExampleTableRequest.IndexKey\x12\x34\n\x02to\x18\x02 \x01(\x0b\x32(.testpb.ListExampleTableRequest.IndexKeyB\x07\n\x05query\"}\n\x18ListExampleTableResponse\x12$\n\x06values\x18\x01 \x03(\x0b\x32\x14.testpb.ExampleTable\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"1\n#GetExampleAutoIncrementTableRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"X\n$GetExampleAutoIncrementTableResponse\x12\x30\n\x05value\x18\x01 \x01(\x0b\x32!.testpb.ExampleAutoIncrementTable\"3\n&GetExampleAutoIncrementTableByXRequest\x12\t\n\x01x\x18\x01 \x01(\t\"[\n\'GetExampleAutoIncrementTableByXResponse\x12\x30\n\x05value\x18\x01 \x01(\x0b\x32!.testpb.ExampleAutoIncrementTable\"\xfc\x04\n$ListExampleAutoIncrementTableRequest\x12M\n\x0cprefix_query\x18\x01 \x01(\x0b\x32\x35.testpb.ListExampleAutoIncrementTableRequest.IndexKeyH\x00\x12N\n\x0brange_query\x18\x02 \x01(\x0b\x32\x37.testpb.ListExampleAutoIncrementTableRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1a\xd8\x01\n\x08IndexKey\x12\x46\n\x02id\x18\x01 \x01(\x0b\x32\x38.testpb.ListExampleAutoIncrementTableRequest.IndexKey.IdH\x00\x12\x44\n\x01x\x18\x02 \x01(\x0b\x32\x37.testpb.ListExampleAutoIncrementTableRequest.IndexKey.XH\x00\x1a\x1c\n\x02Id\x12\x0f\n\x02id\x18\x01 \x01(\x04H\x00\x88\x01\x01\x42\x05\n\x03_id\x1a\x19\n\x01X\x12\x0e\n\x01x\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x04\n\x02_xB\x05\n\x03key\x1a\x94\x01\n\nRangeQuery\x12\x43\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x35.testpb.ListExampleAutoIncrementTableRequest.IndexKey\x12\x41\n\x02to\x18\x02 \x01(\x0b\x32\x35.testpb.ListExampleAutoIncrementTableRequest.IndexKeyB\x07\n\x05query\"\x97\x01\n%ListExampleAutoIncrementTableResponse\x12\x31\n\x06values\x18\x01 \x03(\x0b\x32!.testpb.ExampleAutoIncrementTable\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x1c\n\x1aGetExampleSingletonRequest\"F\n\x1bGetExampleSingletonResponse\x12\'\n\x05value\x18\x01 \x01(\x0b\x32\x18.testpb.ExampleSingleton\"(\n\x1aGetExampleTimestampRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"F\n\x1bGetExampleTimestampResponse\x12\'\n\x05value\x18\x01 \x01(\x0b\x32\x18.testpb.ExampleTimestamp\"\xde\x04\n\x1bListExampleTimestampRequest\x12\x44\n\x0cprefix_query\x18\x01 \x01(\x0b\x32,.testpb.ListExampleTimestampRequest.IndexKeyH\x00\x12\x45\n\x0brange_query\x18\x02 \x01(\x0b\x32..testpb.ListExampleTimestampRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1a\xe7\x01\n\x08IndexKey\x12=\n\x02id\x18\x01 \x01(\x0b\x32/.testpb.ListExampleTimestampRequest.IndexKey.IdH\x00\x12=\n\x02ts\x18\x02 \x01(\x0b\x32/.testpb.ListExampleTimestampRequest.IndexKey.TsH\x00\x1a\x1c\n\x02Id\x12\x0f\n\x02id\x18\x01 \x01(\x04H\x00\x88\x01\x01\x42\x05\n\x03_id\x1a\x38\n\x02Ts\x12+\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x05\n\x03_tsB\x05\n\x03key\x1a\x82\x01\n\nRangeQuery\x12:\n\x04\x66rom\x18\x01 \x01(\x0b\x32,.testpb.ListExampleTimestampRequest.IndexKey\x12\x38\n\x02to\x18\x02 \x01(\x0b\x32,.testpb.ListExampleTimestampRequest.IndexKeyB\x07\n\x05query\"\x85\x01\n\x1cListExampleTimestampResponse\x12(\n\x06values\x18\x01 \x03(\x0b\x32\x18.testpb.ExampleTimestamp\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\'\n\x17GetSimpleExampleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x18GetSimpleExampleResponse\x12$\n\x05value\x18\x01 \x01(\x0b\x32\x15.testpb.SimpleExample\"1\n\x1fGetSimpleExampleByUniqueRequest\x12\x0e\n\x06unique\x18\x01 \x01(\t\"H\n GetSimpleExampleByUniqueResponse\x12$\n\x05value\x18\x01 \x01(\x0b\x32\x15.testpb.SimpleExample\"\xca\x04\n\x18ListSimpleExampleRequest\x12\x41\n\x0cprefix_query\x18\x01 \x01(\x0b\x32).testpb.ListSimpleExampleRequest.IndexKeyH\x00\x12\x42\n\x0brange_query\x18\x02 \x01(\x0b\x32+.testpb.ListSimpleExampleRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1a\xe3\x01\n\x08IndexKey\x12>\n\x04name\x18\x01 \x01(\x0b\x32..testpb.ListSimpleExampleRequest.IndexKey.NameH\x00\x12\x42\n\x06unique\x18\x02 \x01(\x0b\x32\x30.testpb.ListSimpleExampleRequest.IndexKey.UniqueH\x00\x1a\"\n\x04Name\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\x1a(\n\x06Unique\x12\x13\n\x06unique\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_uniqueB\x05\n\x03key\x1a|\n\nRangeQuery\x12\x37\n\x04\x66rom\x18\x01 \x01(\x0b\x32).testpb.ListSimpleExampleRequest.IndexKey\x12\x35\n\x02to\x18\x02 \x01(\x0b\x32).testpb.ListSimpleExampleRequest.IndexKeyB\x07\n\x05query\"\x7f\n\x19ListSimpleExampleResponse\x12%\n\x06values\x18\x01 \x03(\x0b\x32\x15.testpb.SimpleExample\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"0\n!GetExampleAutoIncFieldNameRequest\x12\x0b\n\x03\x66oo\x18\x01 \x01(\x04\"T\n\"GetExampleAutoIncFieldNameResponse\x12.\n\x05value\x18\x01 \x01(\x0b\x32\x1f.testpb.ExampleAutoIncFieldName\"\x93\x04\n\"ListExampleAutoIncFieldNameRequest\x12K\n\x0cprefix_query\x18\x01 \x01(\x0b\x32\x33.testpb.ListExampleAutoIncFieldNameRequest.IndexKeyH\x00\x12L\n\x0brange_query\x18\x02 \x01(\x0b\x32\x35.testpb.ListExampleAutoIncFieldNameRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1az\n\x08IndexKey\x12\x46\n\x03\x66oo\x18\x01 \x01(\x0b\x32\x37.testpb.ListExampleAutoIncFieldNameRequest.IndexKey.FooH\x00\x1a\x1f\n\x03\x46oo\x12\x10\n\x03\x66oo\x18\x01 \x01(\x04H\x00\x88\x01\x01\x42\x06\n\x04_fooB\x05\n\x03key\x1a\x90\x01\n\nRangeQuery\x12\x41\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x33.testpb.ListExampleAutoIncFieldNameRequest.IndexKey\x12?\n\x02to\x18\x02 \x01(\x0b\x32\x33.testpb.ListExampleAutoIncFieldNameRequest.IndexKeyB\x07\n\x05query\"\x93\x01\n#ListExampleAutoIncFieldNameResponse\x12/\n\x06values\x18\x01 \x03(\x0b\x32\x1f.testpb.ExampleAutoIncFieldName\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xf9\x0b\n\x16TestSchemaQueryService\x12T\n\x0fGetExampleTable\x12\x1e.testpb.GetExampleTableRequest\x1a\x1f.testpb.GetExampleTableResponse\"\x00\x12l\n\x17GetExampleTableByU64Str\x12&.testpb.GetExampleTableByU64StrRequest\x1a\'.testpb.GetExampleTableByU64StrResponse\"\x00\x12W\n\x10ListExampleTable\x12\x1f.testpb.ListExampleTableRequest\x1a .testpb.ListExampleTableResponse\"\x00\x12{\n\x1cGetExampleAutoIncrementTable\x12+.testpb.GetExampleAutoIncrementTableRequest\x1a,.testpb.GetExampleAutoIncrementTableResponse\"\x00\x12\x84\x01\n\x1fGetExampleAutoIncrementTableByX\x12..testpb.GetExampleAutoIncrementTableByXRequest\x1a/.testpb.GetExampleAutoIncrementTableByXResponse\"\x00\x12~\n\x1dListExampleAutoIncrementTable\x12,.testpb.ListExampleAutoIncrementTableRequest\x1a-.testpb.ListExampleAutoIncrementTableResponse\"\x00\x12`\n\x13GetExampleSingleton\x12\".testpb.GetExampleSingletonRequest\x1a#.testpb.GetExampleSingletonResponse\"\x00\x12`\n\x13GetExampleTimestamp\x12\".testpb.GetExampleTimestampRequest\x1a#.testpb.GetExampleTimestampResponse\"\x00\x12\x63\n\x14ListExampleTimestamp\x12#.testpb.ListExampleTimestampRequest\x1a$.testpb.ListExampleTimestampResponse\"\x00\x12W\n\x10GetSimpleExample\x12\x1f.testpb.GetSimpleExampleRequest\x1a .testpb.GetSimpleExampleResponse\"\x00\x12o\n\x18GetSimpleExampleByUnique\x12\'.testpb.GetSimpleExampleByUniqueRequest\x1a(.testpb.GetSimpleExampleByUniqueResponse\"\x00\x12Z\n\x11ListSimpleExample\x12 .testpb.ListSimpleExampleRequest\x1a!.testpb.ListSimpleExampleResponse\"\x00\x12u\n\x1aGetExampleAutoIncFieldName\x12).testpb.GetExampleAutoIncFieldNameRequest\x1a*.testpb.GetExampleAutoIncFieldNameResponse\"\x00\x12x\n\x1bListExampleAutoIncFieldName\x12*.testpb.ListExampleAutoIncFieldNameRequest\x1a+.testpb.ListExampleAutoIncFieldNameResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'testpb.test_schema_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETEXAMPLETABLEREQUEST']._serialized_start=145
  _globals['_GETEXAMPLETABLEREQUEST']._serialized_end=208
  _globals['_GETEXAMPLETABLERESPONSE']._serialized_start=210
  _globals['_GETEXAMPLETABLERESPONSE']._serialized_end=272
  _globals['_GETEXAMPLETABLEBYU64STRREQUEST']._serialized_start=274
  _globals['_GETEXAMPLETABLEBYU64STRREQUEST']._serialized_end=332
  _globals['_GETEXAMPLETABLEBYU64STRRESPONSE']._serialized_start=334
  _globals['_GETEXAMPLETABLEBYU64STRRESPONSE']._serialized_end=404
  _globals['_LISTEXAMPLETABLEREQUEST']._serialized_start=407
  _globals['_LISTEXAMPLETABLEREQUEST']._serialized_end=1333
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY']._serialized_start=628
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY']._serialized_end=1200
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_U32I64STR']._serialized_start=921
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_U32I64STR']._serialized_end=1010
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_U64STR']._serialized_start=1012
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_U64STR']._serialized_end=1072
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_STRU32']._serialized_start=1074
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_STRU32']._serialized_end=1134
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_BZSTR']._serialized_start=1136
  _globals['_LISTEXAMPLETABLEREQUEST_INDEXKEY_BZSTR']._serialized_end=1193
  _globals['_LISTEXAMPLETABLEREQUEST_RANGEQUERY']._serialized_start=1202
  _globals['_LISTEXAMPLETABLEREQUEST_RANGEQUERY']._serialized_end=1324
  _globals['_LISTEXAMPLETABLERESPONSE']._serialized_start=1335
  _globals['_LISTEXAMPLETABLERESPONSE']._serialized_end=1460
  _globals['_GETEXAMPLEAUTOINCREMENTTABLEREQUEST']._serialized_start=1462
  _globals['_GETEXAMPLEAUTOINCREMENTTABLEREQUEST']._serialized_end=1511
  _globals['_GETEXAMPLEAUTOINCREMENTTABLERESPONSE']._serialized_start=1513
  _globals['_GETEXAMPLEAUTOINCREMENTTABLERESPONSE']._serialized_end=1601
  _globals['_GETEXAMPLEAUTOINCREMENTTABLEBYXREQUEST']._serialized_start=1603
  _globals['_GETEXAMPLEAUTOINCREMENTTABLEBYXREQUEST']._serialized_end=1654
  _globals['_GETEXAMPLEAUTOINCREMENTTABLEBYXRESPONSE']._serialized_start=1656
  _globals['_GETEXAMPLEAUTOINCREMENTTABLEBYXRESPONSE']._serialized_end=1747
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST']._serialized_start=1750
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST']._serialized_end=2386
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_INDEXKEY']._serialized_start=2010
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_INDEXKEY']._serialized_end=2226
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_INDEXKEY_ID']._serialized_start=2164
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_INDEXKEY_ID']._serialized_end=2192
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_INDEXKEY_X']._serialized_start=2194
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_INDEXKEY_X']._serialized_end=2219
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_RANGEQUERY']._serialized_start=2229
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLEREQUEST_RANGEQUERY']._serialized_end=2377
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLERESPONSE']._serialized_start=2389
  _globals['_LISTEXAMPLEAUTOINCREMENTTABLERESPONSE']._serialized_end=2540
  _globals['_GETEXAMPLESINGLETONREQUEST']._serialized_start=2542
  _globals['_GETEXAMPLESINGLETONREQUEST']._serialized_end=2570
  _globals['_GETEXAMPLESINGLETONRESPONSE']._serialized_start=2572
  _globals['_GETEXAMPLESINGLETONRESPONSE']._serialized_end=2642
  _globals['_GETEXAMPLETIMESTAMPREQUEST']._serialized_start=2644
  _globals['_GETEXAMPLETIMESTAMPREQUEST']._serialized_end=2684
  _globals['_GETEXAMPLETIMESTAMPRESPONSE']._serialized_start=2686
  _globals['_GETEXAMPLETIMESTAMPRESPONSE']._serialized_end=2756
  _globals['_LISTEXAMPLETIMESTAMPREQUEST']._serialized_start=2759
  _globals['_LISTEXAMPLETIMESTAMPREQUEST']._serialized_end=3365
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_INDEXKEY']._serialized_start=2992
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_INDEXKEY']._serialized_end=3223
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_INDEXKEY_ID']._serialized_start=2164
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_INDEXKEY_ID']._serialized_end=2192
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_INDEXKEY_TS']._serialized_start=3160
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_INDEXKEY_TS']._serialized_end=3216
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_RANGEQUERY']._serialized_start=3226
  _globals['_LISTEXAMPLETIMESTAMPREQUEST_RANGEQUERY']._serialized_end=3356
  _globals['_LISTEXAMPLETIMESTAMPRESPONSE']._serialized_start=3368
  _globals['_LISTEXAMPLETIMESTAMPRESPONSE']._serialized_end=3501
  _globals['_GETSIMPLEEXAMPLEREQUEST']._serialized_start=3503
  _globals['_GETSIMPLEEXAMPLEREQUEST']._serialized_end=3542
  _globals['_GETSIMPLEEXAMPLERESPONSE']._serialized_start=3544
  _globals['_GETSIMPLEEXAMPLERESPONSE']._serialized_end=3608
  _globals['_GETSIMPLEEXAMPLEBYUNIQUEREQUEST']._serialized_start=3610
  _globals['_GETSIMPLEEXAMPLEBYUNIQUEREQUEST']._serialized_end=3659
  _globals['_GETSIMPLEEXAMPLEBYUNIQUERESPONSE']._serialized_start=3661
  _globals['_GETSIMPLEEXAMPLEBYUNIQUERESPONSE']._serialized_end=3733
  _globals['_LISTSIMPLEEXAMPLEREQUEST']._serialized_start=3736
  _globals['_LISTSIMPLEEXAMPLEREQUEST']._serialized_end=4322
  _globals['_LISTSIMPLEEXAMPLEREQUEST_INDEXKEY']._serialized_start=3960
  _globals['_LISTSIMPLEEXAMPLEREQUEST_INDEXKEY']._serialized_end=4187
  _globals['_LISTSIMPLEEXAMPLEREQUEST_INDEXKEY_NAME']._serialized_start=4104
  _globals['_LISTSIMPLEEXAMPLEREQUEST_INDEXKEY_NAME']._serialized_end=4138
  _globals['_LISTSIMPLEEXAMPLEREQUEST_INDEXKEY_UNIQUE']._serialized_start=4140
  _globals['_LISTSIMPLEEXAMPLEREQUEST_INDEXKEY_UNIQUE']._serialized_end=4180
  _globals['_LISTSIMPLEEXAMPLEREQUEST_RANGEQUERY']._serialized_start=4189
  _globals['_LISTSIMPLEEXAMPLEREQUEST_RANGEQUERY']._serialized_end=4313
  _globals['_LISTSIMPLEEXAMPLERESPONSE']._serialized_start=4324
  _globals['_LISTSIMPLEEXAMPLERESPONSE']._serialized_end=4451
  _globals['_GETEXAMPLEAUTOINCFIELDNAMEREQUEST']._serialized_start=4453
  _globals['_GETEXAMPLEAUTOINCFIELDNAMEREQUEST']._serialized_end=4501
  _globals['_GETEXAMPLEAUTOINCFIELDNAMERESPONSE']._serialized_start=4503
  _globals['_GETEXAMPLEAUTOINCFIELDNAMERESPONSE']._serialized_end=4587
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST']._serialized_start=4590
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST']._serialized_end=5121
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST_INDEXKEY']._serialized_start=4843
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST_INDEXKEY']._serialized_end=4965
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST_INDEXKEY_FOO']._serialized_start=4927
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST_INDEXKEY_FOO']._serialized_end=4958
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST_RANGEQUERY']._serialized_start=4968
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMEREQUEST_RANGEQUERY']._serialized_end=5112
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMERESPONSE']._serialized_start=5124
  _globals['_LISTEXAMPLEAUTOINCFIELDNAMERESPONSE']._serialized_end=5271
  _globals['_TESTSCHEMAQUERYSERVICE']._serialized_start=5274
  _globals['_TESTSCHEMAQUERYSERVICE']._serialized_end=6803
# @@protoc_insertion_point(module_scope)
